@@ -53,6 +53,7 @@ from .Label import *
 from .Milestone import *
 from .NamedUser import *
 from .Markdown import *
+from .OrganizationHasInMembers import *
 from .Organization import *
 from .PullRequest import *
 from .PullRequestComment import *
@@ -93,3 +94,4 @@ from .Issue174 import *
 from .Issue214 import *
 from .Issue216 import *
 from .Issue278 import *
+from .Issue494 import *
